@@ -862,6 +862,19 @@ on_control_default_sink_changed (GvcMixerControl     *control,
         update_default_sink (manager);
 }
 
+static void
+on_control_stream_removed (GvcMixerControl     *control,
+                           guint                id,
+                           MsdMediaKeysManager *manager)
+{
+        if (manager->priv->stream != NULL) {
+		if (gvc_mixer_stream_get_id (manager->priv->stream) == id) {
+	                g_object_unref (manager->priv->stream);
+			manager->priv->stream = NULL;
+		}
+        }
+}
+
 #endif /* HAVE_PULSE */
 
 static gint
@@ -1037,7 +1050,13 @@ do_action (MsdMediaKeysManager *manager,
                 do_media_action (manager);
                 break;
         case CALCULATOR_KEY:
-                execute (manager, "gcalctool", FALSE, FALSE);
+                if ((cmd = g_find_program_in_path ("mate-calc"))) {
+                        execute (manager, "mate-calc", FALSE, FALSE);
+                } else {
+                        execute (manager, "gcalctool", FALSE, FALSE);
+                }
+
+                g_free (cmd);
                 break;
         case PLAY_KEY:
                 return do_multimedia_player_action (manager, "Play");
@@ -1186,6 +1205,10 @@ msd_media_keys_manager_start (MsdMediaKeysManager *manager,
                           "default-sink-changed",
                           G_CALLBACK (on_control_default_sink_changed),
                           manager);
+        g_signal_connect (manager->priv->volume,
+                          "stream-removed",
+                          G_CALLBACK (on_control_stream_removed),
+                          manager);
 
         gvc_mixer_control_open (manager->priv->volume);
 
